package com.ruoyi.manage.service;

import com.ruoyi.manage.domain.EquipmentManage;

import java.util.List;

/**
 * 设备管理Service接口
 * 
 * @author boman
 * @date 2025-05-07
 */
public interface IEquipmentManageService 
{
    /**
     * 查询设备管理
     * 
     * @param equipmentId 设备管理主键
     * @return 设备管理
     */
    public EquipmentManage selectEquipmentManageByEquipmentId(Long equipmentId);

    /**
     * 查询设备管理列表
     * 
     * @param equipmentManage 设备管理
     * @return 设备管理集合
     */
    public List<EquipmentManage> selectEquipmentManageList(EquipmentManage equipmentManage);

    /**
     * 新增设备管理
     * 
     * @param equipmentManage 设备管理
     * @return 结果
     */
    public int insertEquipmentManage(EquipmentManage equipmentManage);

    /**
     * 修改设备管理
     * 
     * @param equipmentManage 设备管理
     * @return 结果
     */
    public int updateEquipmentManage(EquipmentManage equipmentManage);

    /**
     * 批量删除设备管理
     * 
     * @param equipmentIds 需要删除的设备管理主键集合
     * @return 结果
     */
    public int deleteEquipmentManageByEquipmentIds(Long[] equipmentIds);

    /**
     * 删除设备管理信息
     * 
     * @param equipmentId 设备管理主键
     * @return 结果
     */
    public int deleteEquipmentManageByEquipmentId(Long equipmentId);
}
